import { observable, computed } from "mobx";
import { IntervalTree } from "node-interval-tree";

export default class Store {

    @observable content            = '';
    @observable selectionStart     = 0;
    @observable selectionEnd       = 0;
    @observable scrollTop          = 0.0;
    @observable scrollLeft         = 0.0;
    tree                           = null;
    @observable selectedComponents = [];
    @observable selectedTypes      = [];
    @observable selectedTextType   = '';

    constructor(){
        window.s = this;
        //this.setContent(require('raw-loader!../demo.md'));
        this.tree = new IntervalTree();
        //console.log(this.content.length);
    }

    setContent(content){
        this.content = content.replace(/(?:\r\n|\r|\n)/g, '\n');
        this.tree    = new IntervalTree();
    }

    // textarea

    onContentChange(content, selectionStart, selectionEnd){
        this.setContent(content);
        this.onSelectionChange(selectionStart, selectionEnd);
        //console.log(' content: '+this.content.length);
    }

    onSelectionChange(selectionStart, selectionEnd){
        this.selectionStart     = selectionStart;
        this.selectionEnd       = selectionEnd;
        this.selectedComponents = this.tree.search(this.selectionStart, this.selectionEnd);
        this.selectedTypes      = this.selectedComponents.map(c => c.name);
        this.selectedTextType   = this.getTextType(this.selectedTypes);
    }

    onScrollChange(scrollTop, scrollLeft){
        this.scrollTop  = scrollTop;
        this.scrollLeft = scrollLeft;
        //console.log(' scroll: ['+this.scrollLeft.toFixed(3)+' | '+this.scrollTop.toFixed(3)+']');
    }

    // markdown
    
    addComponentToTree(start, end, component){
        this.tree.insert({low: start, high: end, name: component});
    }

    isTypeSelected(type){
        return this.selectedTypes.includes(type);
    }

    // helper functions

    splitString(string, start, end){
        return {
            pre:      string.substr(0, start),
            selected: string.substr(start, end - start),
            post:     string.substr(end)
        };
    }

    splitLines(string, start, end){
        var split = this.splitString(string, start, end);
        var firstIndex = split.pre.lastIndexOf("\n");
        if(firstIndex == -1){
            firstIndex = 0;
        }
        var lastIndex = split.post.indexOf("\n");
        if(lastIndex == -1){
            lastIndex = split.post.length;
        }
        var lines = split.pre.substr(firstIndex) + split.selected + split.post.substr(0, lastIndex + 1);
        return {
            pre:   split.pre.substr(0, firstIndex),
            lines: lines.trim().split("\n"),
            post:  split.post.substr(lastIndex + 1)
        };
    }

    getTypesForRange(start, end){
        return this.tree.search(start, end).map(c => c.name);
    }

    getTextType(types){
        var textTypes = ['heading-1', 'heading-2', 'heading-3', 'heading-4', 'heading-5', 'heading-6'];
        for(var i = 0; i < textTypes.length; i++){
            if(types.includes(textTypes[i])){
                return textTypes[i];
            }
        }
        return 'paragraph';
    }

}