import React from 'react';
import Highlight from 'react-highlight';
import katex from 'katex';
import renderHTML from 'react-render-html';
import ErrorCard from '../ErrorCard.js';
import PlotlyChart from './PlotlyChart.js';


export default class Code extends React.Component {

    render(){
        var code = null;
        try {
            switch(this.props.language){
                case 'math':
                    code = (
                        <p class="katex">
                            {renderHTML(katex.renderToString(this.props.value))}
                        </p>
                    );
                    break;
                case 'plotly':
                    var tmp = JSON.parse(this.props.value);
                    code = <PlotlyChart data={tmp.data} layout={tmp.layout} config={tmp.config} />;
                    break;
                default:
                    console.log(this.props.language);
                    code = (
                        <Highlight class={this.props.language}>
                            {this.props.value}
                        </Highlight>
                    );
                break;
            }
        } catch (e) {
            code = <ErrorCard message={e.message} />;
        }
        return code;
    }
}